[Solar-svn] Revision 3165

pmjones at solarphp.com pmjones at solarphp.com
Sat May 17 08:07:27 CDT 2008


Solar_Sql_Adapter and Solar_Sql_Model_Cache: [CHG] Cache under "$prefix/table/..." vice "$prefix/tables/...".



Modified: trunk/Solar/Sql/Adapter.php
===================================================================
--- trunk/Solar/Sql/Adapter.php	2008-05-17 01:27:52 UTC (rev 3164)
+++ trunk/Solar/Sql/Adapter.php	2008-05-17 13:07:27 UTC (rev 3165)
@@ -1399,7 +1399,7 @@
      */
     public function fetchTableCols($table)
     {
-        $key = $this->_getCacheKey("tables/$table/cols");
+        $key = $this->_getCacheKey("table/$table/cols");
         $result = $this->_cache->fetch($key);
         if (! $result) {
             $result = $this->_fetchTableCols($table);

Modified: trunk/Solar/Sql/Model/Cache.php
===================================================================
--- trunk/Solar/Sql/Model/Cache.php	2008-05-17 01:27:52 UTC (rev 3164)
+++ trunk/Solar/Sql/Model/Cache.php	2008-05-17 13:07:27 UTC (rev 3165)
@@ -112,7 +112,7 @@
      * Technically, this just increases the data version number.  This means
      * that older versions will no longer be valid, causing a cache miss.
      * 
      * The version entry is keyed under `$prefix/tables/$tables/data_version`.
      * 
      * @return void
      * 
@@ -120,7 +120,7 @@
     public function delete()
     {
         $key = $this->_prefix
-             . "/tables"
+             . "/table"
              . "/{$this->_model->table_name}"
              . "/data_version";
         
@@ -147,7 +147,7 @@
      * 
      * Gets the key for a cache entry based on fetch parameters for a select.
      * 
-     * The entry is keyed under `$prefix/tables/$table/data/$version/$hash`,
+     * The entry is keyed under `$prefix/table/$table/data/$version/$hash`,
      * where $hash is an MD5 hash of the serialized parameters.
      * 
      * If the params include a `cache_key` entry, that value is used instead
@@ -172,7 +172,7 @@
         }
         
         $key = $this->_prefix
-             . "/tables"
+             . "/table"
              . "/{$this->_model->table_name}"
              . "/data"
              . "/$version"
@@ -221,7 +221,7 @@
      * 
      * Fetches the current model data version from the cache.
      * 
-     * The entry is keyed under `$prefix/tables/$table/data_version`.
+     * The entry is keyed under `$prefix/table/$table/data_version`.
      * 
      * @return int The model data version.
      * 
@@ -229,7 +229,7 @@
     protected function _fetchVersion()
     {
         $key = $this->_prefix
-             . "/tables"
+             . "/table"
              . "/{$this->_model->table_name}"
              . "/data_version";
         
@@ -112,7 +112,7 @@
      * that older versions will no longer be valid, causing a cache miss.
      * 
-     * The version entry is keyed under `$prefix/tables/$tables/data_version`.
+     * The version entry is keyed under `$prefix/table/$table/data_version`.
      * 
      * @return void




More information about the Solar-svn mailing list